@@ -40,7 +40,6 @@ public:
 
 public:
     bool open() override;
-    bool readData(QByteArray& buffer, qint64 readOffset, qint64 size) override;
     qint64 length() const override;
 
     bool overlaps(const CopyTarget&) const override {
@@ -52,6 +51,9 @@ public:
     qint64 lastByte() const override {
         return length();    /**< @return equal to length for file. @see length() */
     }
+    QString path() const override {
+        return m_File.fileName();
+    }
 
 protected:
     QFile& file() {
