@@ -39,6 +39,7 @@
 #include <QStorageInfo>
 #include <QString>
 #include <QUuid>
+#include <QWidget>
 
 #include <KLocalizedString>
 #include <KPasswordDialog>
@@ -61,8 +62,9 @@ FileSystem::CommandSupportType luks::m_GetUUID = FileSystem::cmdSupportNone;
 luks::luks(qint64 firstsector,
            qint64 lastsector,
            qint64 sectorsused,
-           const QString& label)
-    : FileSystem(firstsector, lastsector, sectorsused, label, FileSystem::Luks)
+           const QString& label,
+           FileSystem::Type t)
+    : FileSystem(firstsector, lastsector, sectorsused, label, t)
     , m_innerFs(nullptr)
     , m_isCryptOpen(false)
     , m_cryptsetupFound(m_Create != cmdSupportNone)
@@ -125,11 +127,11 @@ bool luks::create(Report& report, const QString& deviceNode)
                                 QStringLiteral("512"),
                                 QStringLiteral("--batch-mode"),
                                 QStringLiteral("--force-password"),
+                                QStringLiteral("--type"), QStringLiteral("luks1"),
                                 QStringLiteral("luksFormat"),
                                 deviceNode });
-    if (!( createCmd.start(-1) &&
-                createCmd.write(m_passphrase.toLocal8Bit() + '\n') == m_passphrase.toLocal8Bit().length() + 1 &&
-                createCmd.waitFor() && createCmd.exitCode() == 0))
+    if (!( createCmd.write(m_passphrase.toLocal8Bit() + '\n') &&
+                createCmd.start(-1) && createCmd.exitCode() == 0))
     {
         return false;
     }
@@ -139,9 +141,10 @@ bool luks::create(Report& report, const QString& deviceNode)
                                 deviceNode,
                                 suggestedMapperName(deviceNode) });
 
-    if (!( openCmd.start(-1) &&  openCmd.write(m_passphrase.toLocal8Bit() + '\n') == m_passphrase.toLocal8Bit().length() + 1 && openCmd.waitFor()))
+    if (!( openCmd.write(m_passphrase.toLocal8Bit() + '\n') && openCmd.start(-1)))
         return false;
 
+    setPayloadSize();
     scan(deviceNode);
 
     if (mapperName().isEmpty())
@@ -165,12 +168,12 @@ QString luks::unmountTitle() const
 
 QString luks::cryptOpenTitle() const
 {
-    return xi18nc("@title:menu", "Decrypt");
+    return xi18nc("@title:menu", "Unlock");
 }
 
 QString luks::cryptCloseTitle() const
 {
-    return xi18nc("@title:menu", "Deactivate");
+    return xi18nc("@title:menu", "Lock");
 }
 
 void luks::setPassphrase(const QString& passphrase)
@@ -258,12 +261,12 @@ bool luks::cryptOpen(QWidget* parent, const QString& deviceNode)
     QString passphrase = dlg.password();
     ExternalCommand openCmd(QStringLiteral("cryptsetup"),
                               { QStringLiteral("open"),
+                                QStringLiteral("--tries"), QStringLiteral("1"),
                                 deviceNode,
                                 suggestedMapperName(deviceNode) });
 
-    if (!( openCmd.start(-1) &&
-                    openCmd.write(passphrase.toLocal8Bit() + '\n') == passphrase.toLocal8Bit().length() + 1 &&
-                    openCmd.waitFor() && openCmd.exitCode() == 0) )
+    if (!( openCmd.write(passphrase.toLocal8Bit() + '\n') &&
+                    openCmd.start(-1) && openCmd.exitCode() == 0) )
         return false;
 
     if (m_innerFs) {
@@ -282,8 +285,8 @@ bool luks::cryptOpen(QWidget* parent, const QString& deviceNode)
     if (!m_isCryptOpen)
         return false;
 
-    for (auto &p : LVM::pvList)
-        if (p.isLuks() && p.partition()->deviceNode() == deviceNode && p.partition()->fileSystem().type() == FileSystem::Lvm2_PV)
+    for (auto &p : LVM::pvList::list())
+        if (p.isLuks() && p.partition()->deviceNode() == deviceNode && p.partition()->fileSystem().type() == FileSystem::Type::Lvm2_PV)
             p.setLuks(false);
 
     m_passphrase = passphrase;
@@ -321,7 +324,7 @@ bool luks::cryptClose(const QString& deviceNode)
 
     m_isCryptOpen = (m_innerFs != nullptr);
 
-    for (auto &p : LVM::pvList)
+    for (auto &p : LVM::pvList::list())
         if (!p.isLuks() && p.partition()->deviceNode() == deviceNode)
             p.setLuks(true);
 
@@ -460,7 +463,7 @@ FileSystem::Type luks::type() const
 {
     if (m_isCryptOpen && m_innerFs)
         return m_innerFs->type();
-    return FileSystem::Luks;
+    return FileSystem::Type::Luks;
 }
 
 QString luks::suggestedMapperName(const QString& deviceNode) const
@@ -489,19 +492,18 @@ bool luks::resize(Report& report, const QString& deviceNode, qint64 newLength) c
     if (mapperName().isEmpty())
         return false;
 
-    qint64 payloadLength = newLength - payloadOffset();
     if ( newLength - length() * sectorSize() > 0 )
     {
         ExternalCommand cryptResizeCmd(report, QStringLiteral("cryptsetup"), { QStringLiteral("resize"), mapperName() });
         report.line() << xi18nc("@info:progress", "Resizing LUKS crypt on partition <filename>%1</filename>.", deviceNode);
 
         if (cryptResizeCmd.run(-1) && cryptResizeCmd.exitCode() == 0)
-            return m_innerFs->resize(report, mapperName(), payloadLength);
+            return m_innerFs->resize(report, mapperName(), m_PayloadSize);
     }
-    else if (m_innerFs->resize(report, mapperName(), payloadLength))
+    else if (m_innerFs->resize(report, mapperName(), m_PayloadSize))
     {
         ExternalCommand cryptResizeCmd(report, QStringLiteral("cryptsetup"),
-                {  QStringLiteral("--size"), QString::number(payloadLength / 512), // LUKS payload length is specified in multiples of 512 bytes
+                {  QStringLiteral("--size"), QString::number(m_PayloadSize / 512), // LUKS1 payload length is specified in multiples of 512 bytes
                    QStringLiteral("resize"), mapperName() });
         report.line() << xi18nc("@info:progress", "Resizing LUKS crypt on partition <filename>%1</filename>.", deviceNode);
         if (cryptResizeCmd.run(-1) && cryptResizeCmd.exitCode() == 0)
@@ -573,7 +575,7 @@ void luks::getMapperName(const QString& deviceNode)
     m_MapperName = QString();
 
     if (cmd.run(-1) && cmd.exitCode() == 0) {
-        const QJsonDocument jsonDocument = QJsonDocument::fromJson(cmd.output().toLocal8Bit());
+        const QJsonDocument jsonDocument = QJsonDocument::fromJson(cmd.rawOutput());
         QJsonObject jsonObject = jsonDocument.object();
         const QJsonArray jsonArray = jsonObject[QLatin1String("blockdevices")].toArray();
         for (const auto &deviceLine : jsonArray) {
@@ -588,8 +590,7 @@ void luks::getMapperName(const QString& deviceNode)
 
 void luks::getLuksInfo(const QString& deviceNode)
 {
-    ExternalCommand cmd(QStringLiteral("cryptsetup"),
-                        { QStringLiteral("luksDump"), deviceNode });
+    ExternalCommand cmd(QStringLiteral("cryptsetup"), { QStringLiteral("luksDump"), deviceNode });
     if (cmd.run(-1) && cmd.exitCode() == 0) {
         QRegularExpression re(QStringLiteral("Cipher name:\\s+(\\w+)"));
         QRegularExpressionMatch rem = re.match(cmd.output());
@@ -645,19 +646,19 @@ bool luks::canEncryptType(FileSystem::Type type)
 {
     switch (type)
     {
-        case Btrfs:
-        case F2fs:
-        case Ext2:
-        case Ext3:
-        case Ext4:
-        case Jfs:
-        case LinuxSwap:
-        case Lvm2_PV:
-        case Nilfs2:
-        case ReiserFS:
-        case Reiser4:
-        case Xfs:
-        case Zfs:
+        case Type::Btrfs:
+        case Type::F2fs:
+        case Type::Ext2:
+        case Type::Ext3:
+        case Type::Ext4:
+        case Type::Jfs:
+        case Type::LinuxSwap:
+        case Type::Lvm2_PV:
+        case Type::Nilfs2:
+        case Type::ReiserFS:
+        case Type::Reiser4:
+        case Type::Xfs:
+        case Type::Zfs:
             return true;
         default:
             return false;
@@ -666,6 +667,7 @@ bool luks::canEncryptType(FileSystem::Type type)
 
 void luks::initLUKS()
 {
+    setPayloadSize();
     QString mapperNode = mapperName();
     bool isCryptOpen = !mapperNode.isEmpty();
     setCryptOpen(isCryptOpen);
@@ -675,4 +677,22 @@ void luks::initLUKS()
     }
 }
 
+void luks::setPayloadSize()
+{
+    ExternalCommand dmsetupCmd(QStringLiteral("dmsetup"), { QStringLiteral("table"), mapperName() });
+    dmsetupCmd.run();
+    QRegularExpression re(QStringLiteral("\\d+ (\\d+)"));
+    QRegularExpressionMatch rem = re.match(dmsetupCmd.output());
+    if (rem.hasMatch())
+        m_PayloadSize = rem.captured(1).toLongLong() * sectorSize();
+}
+
+bool luks::testPassphrase(const QString& deviceNode, const QString& passphrase) const {
+    ExternalCommand cmd(QStringLiteral("cryptsetup"), { QStringLiteral("open"), QStringLiteral("--tries"), QStringLiteral("1"), QStringLiteral("--test-passphrase"), deviceNode });
+    if (cmd.write(passphrase.toLocal8Bit() + '\n') && cmd.start(-1) && cmd.exitCode() == 0)
+        return true;
+
+    return false;
+}
+
 }
