@@ -57,7 +57,7 @@ bool CheckOperation::targets(const Partition& p) const
 
 QString CheckOperation::description() const
 {
-    return xi18nc("@info/plain", "Check and repair partition <filename>%1</filename> (%2, %3)", checkedPartition().deviceNode(), Capacity::formatByteSize(checkedPartition().capacity()), checkedPartition().fileSystem().name());
+    return xi18nc("@info:status", "Check and repair partition <filename>%1</filename> (%2, %3)", checkedPartition().deviceNode(), Capacity::formatByteSize(checkedPartition().capacity()), checkedPartition().fileSystem().name());
 }
 
 /** Can a Partition be checked?
@@ -70,7 +70,7 @@ bool CheckOperation::canCheck(const Partition* p)
         return false;
 
     if (p->isMounted())
-        return false;
+        return p->fileSystem().supportCheckOnline() != FileSystem::cmdSupportNone;
 
     return p->fileSystem().supportCheck() != FileSystem::cmdSupportNone;
 }
